femap\_neutral\_parser package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   femap_neutral_parser.blocks

Submodules
----------

femap\_neutral\_parser.parser module
------------------------------------

.. automodule:: femap_neutral_parser.parser
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: femap_neutral_parser
   :members:
   :undoc-members:
   :show-inheritance:
